#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @XZGUtil    : 2020-12-23 21:28
# @Site    :
# @File    : __init__.py.py
# @Software: PyCharm
"""
from XZGUtil import DBHelper  数据库相关
from XZGUtil import dealFile  读取，写入excel、csv表格文件
from XZGUtil import downFile  下载文件
from XZGUtil import encAndDec 加密解密
from XZGUtil import logger    日志打印
from XZGUtil import messageUtil  发送钉钉消息、邮件
from XZGUtil import re_xzg     正则
from XZGUtil import timeUtil   时间相关
from XZGUtil import updateSpider  配置文件读取写入
from XZGUtil import raspberryScan  树莓派ip扫描
from XZGUtil import timer  定时器
"""
